@@ -136,9 +136,11 @@ class BaseAgent(KoiledModel):
     async def astep(self):
         await self.process(await self._inqueue.get())
 
-    async def astart(self):
+    async def astart(self, instance_id: str = "default"):
         await self.aregister_definitions()
 
+        await self.transport.aconnect(instance_id=instance_id)
+
         data = await self.transport.list_provisions()
 
         for prov in data:
@@ -172,11 +174,11 @@ class BaseAgent(KoiledModel):
             self.running = False
             raise
 
-    async def aprovide(self):
+    async def aprovide(self, instance_id: str = "default"):
         logger.info(
             f"Launching provisioning task. We are running {self.transport.instance_id}"
         )
-        await self.astart()
+        await self.astart(instance_id=instance_id)
         await self.aloop()
 
     async def __aenter__(self):
