@@ -10,10 +10,10 @@ def get_default_structure_registry() -> StructureRegistry:
         DEFAULT_STRUCTURE_REGISTRY = StructureRegistry()
 
         DEFAULT_STRUCTURE_REGISTRY.register_as_structure(
-            TemplateFragment, "@arkitekt/template", expand=aget_template
+            TemplateFragment, "@rekuest/template", expand=aget_template
         )
         DEFAULT_STRUCTURE_REGISTRY.register_as_structure(
-            NodeFragment, "@arkitekt/node", expand=afind
+            NodeFragment, "@rekuest/node", expand=afind
         )
 
     return DEFAULT_STRUCTURE_REGISTRY
